# API-STOCK
## Api useful  to get stock data

[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://travis-ci.org/joemccann/dillinger)

## Features

- Get Historical Stock Price Values 

## Tech

API-STOCK uses a number of open source projects to work properly:

- Python


## Installation

API-STOCK requires [Python](python.org)  v3x to run.
Install 
```
pip install api-stock==0.1
```

#### Building for source

For production release:

```sh
gulp build --prod
```

Generating pre-built zip archives for distribution:

```sh
gulp build dist --prod
```

## License

MIT

**Free Library, Hell Yeah!**